#
# spec file for package python-flask-oidc
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pypi_name flask-oidc
Name:           python-%{pypi_name}
Version:        2.3.1
Release:        1.1
Summary:        OpenID Connect support for Flask
License:        BSD-2-Clause
URL:            https://github.com/fedora-infra/%{pypi_name}
Source0:        https://pypi.io/packages/source/f/%{pypi_name}/flask_oidc-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Don't fail a test due to quoting
Patch0:         ignore-quoting-madness.patch
BuildRequires:  %{python_module Authlib >= 1.2}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.20}
BuildRequires:  %{python_module responses}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Authlib >= 1.2
Requires:       python-Flask
Requires:       python-blinker >= 1.4
Requires:       python-requests >= 2.20
BuildArch:      noarch
%python_subpackages

%description
This library should work with any standards compliant OpenID Connect provider.

It has been tested with:
* Ipsilon

%prep
%autosetup -p1 -n flask_oidc-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSES/BSD-2-Clause.txt
%{python_sitelib}/flask_oidc/
%{python_sitelib}/flask_oidc-%{version}.dist-info

%changelog
* Tue May  6 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.3.1:
  * Important
    + Rebased the Flask OIDC API on Authlib.
  * Added
    + Make the client_secrets.json file optional when OIDC is disabled
    + Support Python 3.12
    + Re-add redirect_to_auth_server() for compatibility with v1.x
    + Add a user model to flask.g with convenience properties
    + Add signals to hook into the login and logout process
  * Fixed
    + Include the root_path when redirecting to the custom callback route
    + Avoid redirect loops when the app is not mounted on the webserver root
    + Handle token expiration when there is no refresh_token or no token URL
    + Use the OIDC_CALLBACK_ROUTE with the ID provider when it is defined,
    instead of the default
    + Auto-renew tokens when they have expired (if possible), as version 1.x
    used to do
    + Avoid a redirect loop on logout when the token is expired
    + Don't crash if the client_secrets don't contain a userinfo_uri key
    + Handle older versions of Werkzeug.
  * Changed
    + Ship the licenses files in the sdist
    + Don't request the profile scope by default, as version 1.x used to do.
  * Deprecated
    + Configuration option OIDC_USERINFO_URL (and the userinfo_uri key in
    client_secrets)
- Switch to pyproject macros.
- Add patch ignore-quoting-madness.patch:
  * Ignore quoting madness that is different for each Python version.
- Drop patch authlib.patch, included upstream.
- Run the testsuite, tests are included.
* Thu Apr 13 2023 pgajdos@suse.com
- authlib.patch removes dependency on six by the way
- modified patches
  %% authlib.patch (refreshed)
* Tue Sep 20 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add authlib.patch to remove the oauth2client dependency
  gh#puiterwijk/flask-oidc#138
* Sat Jul 24 2021 Neal Gompa <ngompa13@gmail.com>
- Drop running tests (there are no tests in the tarball)
* Sat Jan 30 2021 Neal Gompa <ngompa13@gmail.com>
- Adapt for new singlespec style
* Sat Apr 25 2020 Neal Gompa <ngompa13@gmail.com>
- Initial packaging
